@@ -102,19 +102,15 @@ class KemonoExtractor(Extractor):
                 post["username"] = creator["name"]
 
             if comments:
-                try:
-                    post["comments"] = self.api.creator_post_comments(
-                        service, creator_id, post["id"])
-                except exception.HttpError:
+                post["comments"] = cmts = self.api.creator_post_comments(
+                    service, creator_id, post["id"])
+                if not isinstance(cmts, list):
+                    self.log.debug("%s/%s: %s", creator_id, post["id"], cmts)
                     post["comments"] = ()
             if dms is not None:
                 if dms is True:
                     dms = self.api.creator_dms(
                         post["service"], post["user"])
-                    try:
-                        dms = dms["props"]["dms"]
-                    except Exception:
-                        dms = ()
                 post["dms"] = dms
             if announcements is not None:
                 if announcements is True:
@@ -155,7 +151,8 @@ class KemonoExtractor(Extractor):
                     file["extension"] = ext
                 elif ext == "txt" and file["extension"] != "txt":
                     file["_http_validate"] = _validate
-                elif ext in exts_archive:
+                elif ext in exts_archive or \
+                        ext == "bin" and file["extension"] in exts_archive:
                     file["type"] = "archive"
                     if archives:
                         try:
@@ -245,16 +242,15 @@ class KemonoExtractor(Extractor):
     def _revisions_post(self, post):
         post["revision_id"] = 0
 
-        try:
-            revs = self.api.creator_post_revisions(
-                post["service"], post["user"], post["id"])
-        except exception.HttpError:
+        revs = self.api.creator_post_revisions(
+            post["service"], post["user"], post["id"])
+        if not revs:
             post["revision_hash"] = self._revision_hash(post)
             post["revision_index"] = 1
             post["revision_count"] = 1
             return (post,)
-        revs.insert(0, post)
 
+        revs.insert(0, post)
         for rev in revs:
             rev["revision_hash"] = self._revision_hash(rev)
 
@@ -325,25 +321,14 @@ class KemonoUserExtractor(KemonoExtractor):
     def posts(self):
         _, _, service, creator_id, query = self.groups
         params = text.parse_query(query)
-        tag = params.get("tag")
 
-        endpoint = self.config("endpoint")
-        if endpoint == "legacy+":
-            endpoint = self._posts_legacy_plus
-        elif endpoint == "legacy" or tag:
-            endpoint = self.api.creator_posts_legacy
+        if self.config("endpoint") in ("posts+", "legacy+"):
+            endpoint = self.api.creator_posts_expand
         else:
             endpoint = self.api.creator_posts
 
         return endpoint(service, creator_id,
-                        params.get("o"), params.get("q"), tag)
-
-    def _posts_legacy_plus(self, service, creator_id,
-                           offset=0, query=None, tags=None):
-        for post in self.api.creator_posts_legacy(
-                service, creator_id, offset, query, tags):
-            yield self.api.creator_post(
-                service, creator_id, post["id"])["post"]
+                        params.get("o"), params.get("q"), params.get("tag"))
 
 
 class KemonoPostsExtractor(KemonoExtractor):
@@ -422,7 +407,11 @@ class KemonoDiscordExtractor(KemonoExtractor):
             r"(/[A-Za-z0-9-._~:/?#\[\]@!$&'()*+,;%=]+)").findall
         find_hash = util.re(HASH_PATTERN).match
 
-        posts = self.api.discord_channel(channel_id)
+        if (order := self.config("order-posts")) and order[0] in ("r", "d"):
+            posts = self.api.discord_channel(channel_id, channel["post_count"])
+        else:
+            posts = self.api.discord_channel(channel_id)
+
         if max_posts := self.config("max-posts"):
             posts = itertools.islice(posts, max_posts)
 
@@ -578,6 +567,7 @@ class KemonoAPI():
     def __init__(self, extractor):
         self.extractor = extractor
         self.root = extractor.root + "/api/v1"
+        self.headers = {"Accept": "text/css"}
 
     def posts(self, offset=0, query=None, tags=None):
         endpoint = "/posts"
@@ -589,20 +579,21 @@ class KemonoAPI():
         return self._call(endpoint)
 
     def creators(self):
-        endpoint = "/creators.txt"
+        endpoint = "/creators"
         return self._call(endpoint)
 
     def creator_posts(self, service, creator_id,
                       offset=0, query=None, tags=None):
-        endpoint = f"/{service}/user/{creator_id}"
-        params = {"q": query, "tag": tags, "o": offset}
+        endpoint = f"/{service}/user/{creator_id}/posts"
+        params = {"o": offset, "tag": tags, "q": query}
         return self._pagination(endpoint, params, 50)
 
-    def creator_posts_legacy(self, service, creator_id,
+    def creator_posts_expand(self, service, creator_id,
                              offset=0, query=None, tags=None):
-        endpoint = f"/{service}/user/{creator_id}/posts-legacy"
-        params = {"o": offset, "tag": tags, "q": query}
-        return self._pagination(endpoint, params, 50, "results")
+        for post in self.creator_posts(
+                service, creator_id, offset, query, tags):
+            yield self.creator_post(
+                service, creator_id, post["id"])["post"]
 
     def creator_announcements(self, service, creator_id):
         endpoint = f"/{service}/user/{creator_id}/announcements"
@@ -622,11 +613,11 @@ class KemonoAPI():
 
     def creator_post_comments(self, service, creator_id, post_id):
         endpoint = f"/{service}/user/{creator_id}/post/{post_id}/comments"
-        return self._call(endpoint)
+        return self._call(endpoint, fatal=False)
 
     def creator_post_revisions(self, service, creator_id, post_id):
         endpoint = f"/{service}/user/{creator_id}/post/{post_id}/revisions"
-        return self._call(endpoint)
+        return self._call(endpoint, fatal=False)
 
     def creator_profile(self, service, creator_id):
         endpoint = f"/{service}/user/{creator_id}/profile"
@@ -640,9 +631,12 @@ class KemonoAPI():
         endpoint = f"/{service}/user/{creator_id}/tags"
         return self._call(endpoint)
 
-    def discord_channel(self, channel_id):
+    def discord_channel(self, channel_id, post_count=None):
         endpoint = f"/discord/channel/{channel_id}"
-        return self._pagination(endpoint, {}, 150)
+        if post_count is None:
+            return self._pagination(endpoint, {}, 150)
+        else:
+            return self._pagination_reverse(endpoint, {}, 150, post_count)
 
     def discord_channel_lookup(self, server_id):
         endpoint = f"/discord/channel/lookup/{server_id}"
@@ -657,19 +651,24 @@ class KemonoAPI():
         params = {"type": type}
         return self._call(endpoint, params)
 
-    def _call(self, endpoint, params=None):
-        url = self.root + endpoint
-        response = self.extractor.request(url, params=params)
-        return response.json()
+    def _call(self, endpoint, params=None, headers=None, fatal=True):
+        if headers is None:
+            headers = self.headers
+        else:
+            headers = {**self.headers, **headers}
 
-    def _pagination(self, endpoint, params, batch=50, key=False):
+        return self.extractor.request_json(
+            f"{self.root}{endpoint}", params=params, headers=headers,
+            encoding="utf-8", fatal=fatal)
+
+    def _pagination(self, endpoint, params, batch=50, key=None):
         offset = text.parse_int(params.get("o"))
         params["o"] = offset - offset % batch
 
         while True:
             data = self._call(endpoint, params)
 
-            if key:
+            if key is not None:
                 data = data.get(key)
             if not data:
                 return
@@ -678,3 +677,18 @@ class KemonoAPI():
             if len(data) < batch:
                 return
             params["o"] += batch
+
+    def _pagination_reverse(self, endpoint, params, batch, count):
+        params["o"] = count // batch * batch
+
+        while True:
+            data = self._call(endpoint, params)
+
+            if not data:
+                return
+            data.reverse()
+            yield from data
+
+            if not params["o"]:
+                return
+            params["o"] -= batch
